# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.radius_provider import RadiusProvider

class TestRadiusProvider(unittest.TestCase):
    """RadiusProvider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RadiusProvider:
        """Test RadiusProvider
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RadiusProvider`
        """
        model = RadiusProvider()
        if include_optional:
            return RadiusProvider(
                pk = 56,
                name = '',
                authentication_flow = '',
                authorization_flow = '',
                invalidation_flow = '',
                property_mappings = [
                    ''
                    ],
                component = '',
                assigned_application_slug = '',
                assigned_application_name = '',
                assigned_backchannel_application_slug = '',
                assigned_backchannel_application_name = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                client_networks = '',
                shared_secret = '',
                outpost_set = [
                    ''
                    ],
                mfa_support = True
            )
        else:
            return RadiusProvider(
                pk = 56,
                name = '',
                authorization_flow = '',
                invalidation_flow = '',
                component = '',
                assigned_application_slug = '',
                assigned_application_name = '',
                assigned_backchannel_application_slug = '',
                assigned_backchannel_application_name = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                outpost_set = [
                    ''
                    ],
        )
        """

    def testRadiusProvider(self):
        """Test RadiusProvider"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
